@@ -6,9 +6,9 @@ Type annotations for transfer service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_transfer.type_defs import CreateAccessRequestTypeDef
+    from mypy_boto3_transfer.type_defs import CreateAccessRequestRequestTypeDef
 
-    data: CreateAccessRequestTypeDef = {...}
+    data: CreateAccessRequestRequestTypeDef = {...}
     ```
 """
 import sys
@@ -31,24 +31,24 @@ else:
 
 
 __all__ = (
-    "CreateAccessRequestTypeDef",
-    "CreateAccessResponseResponseTypeDef",
-    "CreateServerRequestTypeDef",
-    "CreateServerResponseResponseTypeDef",
-    "CreateUserRequestTypeDef",
-    "CreateUserResponseResponseTypeDef",
-    "DeleteAccessRequestTypeDef",
-    "DeleteServerRequestTypeDef",
-    "DeleteSshPublicKeyRequestTypeDef",
-    "DeleteUserRequestTypeDef",
-    "DescribeAccessRequestTypeDef",
-    "DescribeAccessResponseResponseTypeDef",
-    "DescribeSecurityPolicyRequestTypeDef",
-    "DescribeSecurityPolicyResponseResponseTypeDef",
-    "DescribeServerRequestTypeDef",
-    "DescribeServerResponseResponseTypeDef",
-    "DescribeUserRequestTypeDef",
-    "DescribeUserResponseResponseTypeDef",
+    "CreateAccessRequestRequestTypeDef",
+    "CreateAccessResponseTypeDef",
+    "CreateServerRequestRequestTypeDef",
+    "CreateServerResponseTypeDef",
+    "CreateUserRequestRequestTypeDef",
+    "CreateUserResponseTypeDef",
+    "DeleteAccessRequestRequestTypeDef",
+    "DeleteServerRequestRequestTypeDef",
+    "DeleteSshPublicKeyRequestRequestTypeDef",
+    "DeleteUserRequestRequestTypeDef",
+    "DescribeAccessRequestRequestTypeDef",
+    "DescribeAccessResponseTypeDef",
+    "DescribeSecurityPolicyRequestRequestTypeDef",
+    "DescribeSecurityPolicyResponseTypeDef",
+    "DescribeServerRequestRequestTypeDef",
+    "DescribeServerResponseTypeDef",
+    "DescribeUserRequestRequestTypeDef",
+    "DescribeUserResponseTypeDef",
     "DescribedAccessTypeDef",
     "DescribedSecurityPolicyTypeDef",
     "DescribedServerTypeDef",
@@ -56,18 +56,18 @@ __all__ = (
     "EndpointDetailsTypeDef",
     "HomeDirectoryMapEntryTypeDef",
     "IdentityProviderDetailsTypeDef",
-    "ImportSshPublicKeyRequestTypeDef",
-    "ImportSshPublicKeyResponseResponseTypeDef",
-    "ListAccessesRequestTypeDef",
-    "ListAccessesResponseResponseTypeDef",
-    "ListSecurityPoliciesRequestTypeDef",
-    "ListSecurityPoliciesResponseResponseTypeDef",
-    "ListServersRequestTypeDef",
-    "ListServersResponseResponseTypeDef",
-    "ListTagsForResourceRequestTypeDef",
-    "ListTagsForResourceResponseResponseTypeDef",
-    "ListUsersRequestTypeDef",
-    "ListUsersResponseResponseTypeDef",
+    "ImportSshPublicKeyRequestRequestTypeDef",
+    "ImportSshPublicKeyResponseTypeDef",
+    "ListAccessesRequestRequestTypeDef",
+    "ListAccessesResponseTypeDef",
+    "ListSecurityPoliciesRequestRequestTypeDef",
+    "ListSecurityPoliciesResponseTypeDef",
+    "ListServersRequestRequestTypeDef",
+    "ListServersResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "ListUsersRequestRequestTypeDef",
+    "ListUsersResponseTypeDef",
     "ListedAccessTypeDef",
     "ListedServerTypeDef",
     "ListedUserTypeDef",
@@ -76,31 +76,31 @@ __all__ = (
     "ProtocolDetailsTypeDef",
     "ResponseMetadataTypeDef",
     "SshPublicKeyTypeDef",
-    "StartServerRequestTypeDef",
-    "StopServerRequestTypeDef",
-    "TagResourceRequestTypeDef",
+    "StartServerRequestRequestTypeDef",
+    "StopServerRequestRequestTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TagTypeDef",
-    "TestIdentityProviderRequestTypeDef",
-    "TestIdentityProviderResponseResponseTypeDef",
-    "UntagResourceRequestTypeDef",
-    "UpdateAccessRequestTypeDef",
-    "UpdateAccessResponseResponseTypeDef",
-    "UpdateServerRequestTypeDef",
-    "UpdateServerResponseResponseTypeDef",
-    "UpdateUserRequestTypeDef",
-    "UpdateUserResponseResponseTypeDef",
+    "TestIdentityProviderRequestRequestTypeDef",
+    "TestIdentityProviderResponseTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateAccessRequestRequestTypeDef",
+    "UpdateAccessResponseTypeDef",
+    "UpdateServerRequestRequestTypeDef",
+    "UpdateServerResponseTypeDef",
+    "UpdateUserRequestRequestTypeDef",
+    "UpdateUserResponseTypeDef",
 )
 
-_RequiredCreateAccessRequestTypeDef = TypedDict(
-    "_RequiredCreateAccessRequestTypeDef",
+_RequiredCreateAccessRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateAccessRequestRequestTypeDef",
     {
         "Role": str,
         "ServerId": str,
         "ExternalId": str,
     },
 )
-_OptionalCreateAccessRequestTypeDef = TypedDict(
-    "_OptionalCreateAccessRequestTypeDef",
+_OptionalCreateAccessRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateAccessRequestRequestTypeDef",
     {
         "HomeDirectory": str,
         "HomeDirectoryType": HomeDirectoryTypeType,
@@ -112,14 +112,14 @@ _OptionalCreateAccessRequestTypeDef = TypedDict(
 )
 
 
-class CreateAccessRequestTypeDef(
-    _RequiredCreateAccessRequestTypeDef, _OptionalCreateAccessRequestTypeDef
+class CreateAccessRequestRequestTypeDef(
+    _RequiredCreateAccessRequestRequestTypeDef, _OptionalCreateAccessRequestRequestTypeDef
 ):
     pass
 
 
-CreateAccessResponseResponseTypeDef = TypedDict(
-    "CreateAccessResponseResponseTypeDef",
+CreateAccessResponseTypeDef = TypedDict(
+    "CreateAccessResponseTypeDef",
     {
         "ServerId": str,
         "ExternalId": str,
@@ -127,8 +127,8 @@ CreateAccessResponseResponseTypeDef = TypedDict(
     },
 )
 
-CreateServerRequestTypeDef = TypedDict(
-    "CreateServerRequestTypeDef",
+CreateServerRequestRequestTypeDef = TypedDict(
+    "CreateServerRequestRequestTypeDef",
     {
         "Certificate": str,
         "Domain": DomainType,
@@ -145,24 +145,24 @@ CreateServerRequestTypeDef = TypedDict(
     total=False,
 )
 
-CreateServerResponseResponseTypeDef = TypedDict(
-    "CreateServerResponseResponseTypeDef",
+CreateServerResponseTypeDef = TypedDict(
+    "CreateServerResponseTypeDef",
     {
         "ServerId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredCreateUserRequestTypeDef = TypedDict(
-    "_RequiredCreateUserRequestTypeDef",
+_RequiredCreateUserRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateUserRequestRequestTypeDef",
     {
         "Role": str,
         "ServerId": str,
         "UserName": str,
     },
 )
-_OptionalCreateUserRequestTypeDef = TypedDict(
-    "_OptionalCreateUserRequestTypeDef",
+_OptionalCreateUserRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateUserRequestRequestTypeDef",
     {
         "HomeDirectory": str,
         "HomeDirectoryType": HomeDirectoryTypeType,
@@ -176,14 +176,14 @@ _OptionalCreateUserRequestTypeDef = TypedDict(
 )
 
 
-class CreateUserRequestTypeDef(
-    _RequiredCreateUserRequestTypeDef, _OptionalCreateUserRequestTypeDef
+class CreateUserRequestRequestTypeDef(
+    _RequiredCreateUserRequestRequestTypeDef, _OptionalCreateUserRequestRequestTypeDef
 ):
     pass
 
 
-CreateUserResponseResponseTypeDef = TypedDict(
-    "CreateUserResponseResponseTypeDef",
+CreateUserResponseTypeDef = TypedDict(
+    "CreateUserResponseTypeDef",
     {
         "ServerId": str,
         "UserName": str,
@@ -191,23 +191,23 @@ CreateUserResponseResponseTypeDef = TypedDict(
     },
 )
 
-DeleteAccessRequestTypeDef = TypedDict(
-    "DeleteAccessRequestTypeDef",
+DeleteAccessRequestRequestTypeDef = TypedDict(
+    "DeleteAccessRequestRequestTypeDef",
     {
         "ServerId": str,
         "ExternalId": str,
     },
 )
 
-DeleteServerRequestTypeDef = TypedDict(
-    "DeleteServerRequestTypeDef",
+DeleteServerRequestRequestTypeDef = TypedDict(
+    "DeleteServerRequestRequestTypeDef",
     {
         "ServerId": str,
     },
 )
 
-DeleteSshPublicKeyRequestTypeDef = TypedDict(
-    "DeleteSshPublicKeyRequestTypeDef",
+DeleteSshPublicKeyRequestRequestTypeDef = TypedDict(
+    "DeleteSshPublicKeyRequestRequestTypeDef",
     {
         "ServerId": str,
         "SshPublicKeyId": str,
@@ -215,24 +215,24 @@ DeleteSshPublicKeyRequestTypeDef = TypedDict(
     },
 )
 
-DeleteUserRequestTypeDef = TypedDict(
-    "DeleteUserRequestTypeDef",
+DeleteUserRequestRequestTypeDef = TypedDict(
+    "DeleteUserRequestRequestTypeDef",
     {
         "ServerId": str,
         "UserName": str,
     },
 )
 
-DescribeAccessRequestTypeDef = TypedDict(
-    "DescribeAccessRequestTypeDef",
+DescribeAccessRequestRequestTypeDef = TypedDict(
+    "DescribeAccessRequestRequestTypeDef",
     {
         "ServerId": str,
         "ExternalId": str,
     },
 )
 
-DescribeAccessResponseResponseTypeDef = TypedDict(
-    "DescribeAccessResponseResponseTypeDef",
+DescribeAccessResponseTypeDef = TypedDict(
+    "DescribeAccessResponseTypeDef",
     {
         "ServerId": str,
         "Access": "DescribedAccessTypeDef",
@@ -240,46 +240,46 @@ DescribeAccessResponseResponseTypeDef = TypedDict(
     },
 )
 
-DescribeSecurityPolicyRequestTypeDef = TypedDict(
-    "DescribeSecurityPolicyRequestTypeDef",
+DescribeSecurityPolicyRequestRequestTypeDef = TypedDict(
+    "DescribeSecurityPolicyRequestRequestTypeDef",
     {
         "SecurityPolicyName": str,
     },
 )
 
-DescribeSecurityPolicyResponseResponseTypeDef = TypedDict(
-    "DescribeSecurityPolicyResponseResponseTypeDef",
+DescribeSecurityPolicyResponseTypeDef = TypedDict(
+    "DescribeSecurityPolicyResponseTypeDef",
     {
         "SecurityPolicy": "DescribedSecurityPolicyTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DescribeServerRequestTypeDef = TypedDict(
-    "DescribeServerRequestTypeDef",
+DescribeServerRequestRequestTypeDef = TypedDict(
+    "DescribeServerRequestRequestTypeDef",
     {
         "ServerId": str,
     },
 )
 
-DescribeServerResponseResponseTypeDef = TypedDict(
-    "DescribeServerResponseResponseTypeDef",
+DescribeServerResponseTypeDef = TypedDict(
+    "DescribeServerResponseTypeDef",
     {
         "Server": "DescribedServerTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DescribeUserRequestTypeDef = TypedDict(
-    "DescribeUserRequestTypeDef",
+DescribeUserRequestRequestTypeDef = TypedDict(
+    "DescribeUserRequestRequestTypeDef",
     {
         "ServerId": str,
         "UserName": str,
     },
 )
 
-DescribeUserResponseResponseTypeDef = TypedDict(
-    "DescribeUserResponseResponseTypeDef",
+DescribeUserResponseTypeDef = TypedDict(
+    "DescribeUserResponseTypeDef",
     {
         "ServerId": str,
         "User": "DescribedUserTypeDef",
@@ -416,8 +416,8 @@ IdentityProviderDetailsTypeDef = TypedDict(
     total=False,
 )
 
-ImportSshPublicKeyRequestTypeDef = TypedDict(
-    "ImportSshPublicKeyRequestTypeDef",
+ImportSshPublicKeyRequestRequestTypeDef = TypedDict(
+    "ImportSshPublicKeyRequestRequestTypeDef",
     {
         "ServerId": str,
         "SshPublicKeyBody": str,
@@ -425,8 +425,8 @@ ImportSshPublicKeyRequestTypeDef = TypedDict(
     },
 )
 
-ImportSshPublicKeyResponseResponseTypeDef = TypedDict(
-    "ImportSshPublicKeyResponseResponseTypeDef",
+ImportSshPublicKeyResponseTypeDef = TypedDict(
+    "ImportSshPublicKeyResponseTypeDef",
     {
         "ServerId": str,
         "SshPublicKeyId": str,
@@ -435,14 +435,14 @@ ImportSshPublicKeyResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListAccessesRequestTypeDef = TypedDict(
-    "_RequiredListAccessesRequestTypeDef",
+_RequiredListAccessesRequestRequestTypeDef = TypedDict(
+    "_RequiredListAccessesRequestRequestTypeDef",
     {
         "ServerId": str,
     },
 )
-_OptionalListAccessesRequestTypeDef = TypedDict(
-    "_OptionalListAccessesRequestTypeDef",
+_OptionalListAccessesRequestRequestTypeDef = TypedDict(
+    "_OptionalListAccessesRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -451,14 +451,14 @@ _OptionalListAccessesRequestTypeDef = TypedDict(
 )
 
 
-class ListAccessesRequestTypeDef(
-    _RequiredListAccessesRequestTypeDef, _OptionalListAccessesRequestTypeDef
+class ListAccessesRequestRequestTypeDef(
+    _RequiredListAccessesRequestRequestTypeDef, _OptionalListAccessesRequestRequestTypeDef
 ):
     pass
 
 
-ListAccessesResponseResponseTypeDef = TypedDict(
-    "ListAccessesResponseResponseTypeDef",
+ListAccessesResponseTypeDef = TypedDict(
+    "ListAccessesResponseTypeDef",
     {
         "NextToken": str,
         "ServerId": str,
@@ -467,8 +467,8 @@ ListAccessesResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListSecurityPoliciesRequestTypeDef = TypedDict(
-    "ListSecurityPoliciesRequestTypeDef",
+ListSecurityPoliciesRequestRequestTypeDef = TypedDict(
+    "ListSecurityPoliciesRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -476,8 +476,8 @@ ListSecurityPoliciesRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListSecurityPoliciesResponseResponseTypeDef = TypedDict(
-    "ListSecurityPoliciesResponseResponseTypeDef",
+ListSecurityPoliciesResponseTypeDef = TypedDict(
+    "ListSecurityPoliciesResponseTypeDef",
     {
         "NextToken": str,
         "SecurityPolicyNames": List[str],
@@ -485,8 +485,8 @@ ListSecurityPoliciesResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListServersRequestTypeDef = TypedDict(
-    "ListServersRequestTypeDef",
+ListServersRequestRequestTypeDef = TypedDict(
+    "ListServersRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -494,8 +494,8 @@ ListServersRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListServersResponseResponseTypeDef = TypedDict(
-    "ListServersResponseResponseTypeDef",
+ListServersResponseTypeDef = TypedDict(
+    "ListServersResponseTypeDef",
     {
         "NextToken": str,
         "Servers": List["ListedServerTypeDef"],
@@ -503,14 +503,14 @@ ListServersResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListTagsForResourceRequestTypeDef = TypedDict(
-    "_RequiredListTagsForResourceRequestTypeDef",
+_RequiredListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "_RequiredListTagsForResourceRequestRequestTypeDef",
     {
         "Arn": str,
     },
 )
-_OptionalListTagsForResourceRequestTypeDef = TypedDict(
-    "_OptionalListTagsForResourceRequestTypeDef",
+_OptionalListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "_OptionalListTagsForResourceRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -519,14 +519,15 @@ _OptionalListTagsForResourceRequestTypeDef = TypedDict(
 )
 
 
-class ListTagsForResourceRequestTypeDef(
-    _RequiredListTagsForResourceRequestTypeDef, _OptionalListTagsForResourceRequestTypeDef
+class ListTagsForResourceRequestRequestTypeDef(
+    _RequiredListTagsForResourceRequestRequestTypeDef,
+    _OptionalListTagsForResourceRequestRequestTypeDef,
 ):
     pass
 
 
-ListTagsForResourceResponseResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseResponseTypeDef",
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
     {
         "Arn": str,
         "NextToken": str,
@@ -535,14 +536,14 @@ ListTagsForResourceResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListUsersRequestTypeDef = TypedDict(
-    "_RequiredListUsersRequestTypeDef",
+_RequiredListUsersRequestRequestTypeDef = TypedDict(
+    "_RequiredListUsersRequestRequestTypeDef",
     {
         "ServerId": str,
     },
 )
-_OptionalListUsersRequestTypeDef = TypedDict(
-    "_OptionalListUsersRequestTypeDef",
+_OptionalListUsersRequestRequestTypeDef = TypedDict(
+    "_OptionalListUsersRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -551,12 +552,14 @@ _OptionalListUsersRequestTypeDef = TypedDict(
 )
 
 
-class ListUsersRequestTypeDef(_RequiredListUsersRequestTypeDef, _OptionalListUsersRequestTypeDef):
+class ListUsersRequestRequestTypeDef(
+    _RequiredListUsersRequestRequestTypeDef, _OptionalListUsersRequestRequestTypeDef
+):
     pass
 
 
-ListUsersResponseResponseTypeDef = TypedDict(
-    "ListUsersResponseResponseTypeDef",
+ListUsersResponseTypeDef = TypedDict(
+    "ListUsersResponseTypeDef",
     {
         "NextToken": str,
         "ServerId": str,
@@ -682,22 +685,22 @@ SshPublicKeyTypeDef = TypedDict(
     },
 )
 
-StartServerRequestTypeDef = TypedDict(
-    "StartServerRequestTypeDef",
+StartServerRequestRequestTypeDef = TypedDict(
+    "StartServerRequestRequestTypeDef",
     {
         "ServerId": str,
     },
 )
 
-StopServerRequestTypeDef = TypedDict(
-    "StopServerRequestTypeDef",
+StopServerRequestRequestTypeDef = TypedDict(
+    "StopServerRequestRequestTypeDef",
     {
         "ServerId": str,
     },
 )
 
-TagResourceRequestTypeDef = TypedDict(
-    "TagResourceRequestTypeDef",
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
     {
         "Arn": str,
         "Tags": List["TagTypeDef"],
@@ -712,15 +715,15 @@ TagTypeDef = TypedDict(
     },
 )
 
-_RequiredTestIdentityProviderRequestTypeDef = TypedDict(
-    "_RequiredTestIdentityProviderRequestTypeDef",
+_RequiredTestIdentityProviderRequestRequestTypeDef = TypedDict(
+    "_RequiredTestIdentityProviderRequestRequestTypeDef",
     {
         "ServerId": str,
         "UserName": str,
     },
 )
-_OptionalTestIdentityProviderRequestTypeDef = TypedDict(
-    "_OptionalTestIdentityProviderRequestTypeDef",
+_OptionalTestIdentityProviderRequestRequestTypeDef = TypedDict(
+    "_OptionalTestIdentityProviderRequestRequestTypeDef",
     {
         "ServerProtocol": ProtocolType,
         "SourceIp": str,
@@ -730,14 +733,15 @@ _OptionalTestIdentityProviderRequestTypeDef = TypedDict(
 )
 
 
-class TestIdentityProviderRequestTypeDef(
-    _RequiredTestIdentityProviderRequestTypeDef, _OptionalTestIdentityProviderRequestTypeDef
+class TestIdentityProviderRequestRequestTypeDef(
+    _RequiredTestIdentityProviderRequestRequestTypeDef,
+    _OptionalTestIdentityProviderRequestRequestTypeDef,
 ):
     pass
 
 
-TestIdentityProviderResponseResponseTypeDef = TypedDict(
-    "TestIdentityProviderResponseResponseTypeDef",
+TestIdentityProviderResponseTypeDef = TypedDict(
+    "TestIdentityProviderResponseTypeDef",
     {
         "Response": str,
         "StatusCode": int,
@@ -747,23 +751,23 @@ TestIdentityProviderResponseResponseTypeDef = TypedDict(
     },
 )
 
-UntagResourceRequestTypeDef = TypedDict(
-    "UntagResourceRequestTypeDef",
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
     {
         "Arn": str,
         "TagKeys": List[str],
     },
 )
 
-_RequiredUpdateAccessRequestTypeDef = TypedDict(
-    "_RequiredUpdateAccessRequestTypeDef",
+_RequiredUpdateAccessRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateAccessRequestRequestTypeDef",
     {
         "ServerId": str,
         "ExternalId": str,
     },
 )
-_OptionalUpdateAccessRequestTypeDef = TypedDict(
-    "_OptionalUpdateAccessRequestTypeDef",
+_OptionalUpdateAccessRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateAccessRequestRequestTypeDef",
     {
         "HomeDirectory": str,
         "HomeDirectoryType": HomeDirectoryTypeType,
@@ -776,14 +780,14 @@ _OptionalUpdateAccessRequestTypeDef = TypedDict(
 )
 
 
-class UpdateAccessRequestTypeDef(
-    _RequiredUpdateAccessRequestTypeDef, _OptionalUpdateAccessRequestTypeDef
+class UpdateAccessRequestRequestTypeDef(
+    _RequiredUpdateAccessRequestRequestTypeDef, _OptionalUpdateAccessRequestRequestTypeDef
 ):
     pass
 
 
-UpdateAccessResponseResponseTypeDef = TypedDict(
-    "UpdateAccessResponseResponseTypeDef",
+UpdateAccessResponseTypeDef = TypedDict(
+    "UpdateAccessResponseTypeDef",
     {
         "ServerId": str,
         "ExternalId": str,
@@ -791,14 +795,14 @@ UpdateAccessResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateServerRequestTypeDef = TypedDict(
-    "_RequiredUpdateServerRequestTypeDef",
+_RequiredUpdateServerRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateServerRequestRequestTypeDef",
     {
         "ServerId": str,
     },
 )
-_OptionalUpdateServerRequestTypeDef = TypedDict(
-    "_OptionalUpdateServerRequestTypeDef",
+_OptionalUpdateServerRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateServerRequestRequestTypeDef",
     {
         "Certificate": str,
         "ProtocolDetails": "ProtocolDetailsTypeDef",
@@ -814,29 +818,29 @@ _OptionalUpdateServerRequestTypeDef = TypedDict(
 )
 
 
-class UpdateServerRequestTypeDef(
-    _RequiredUpdateServerRequestTypeDef, _OptionalUpdateServerRequestTypeDef
+class UpdateServerRequestRequestTypeDef(
+    _RequiredUpdateServerRequestRequestTypeDef, _OptionalUpdateServerRequestRequestTypeDef
 ):
     pass
 
 
-UpdateServerResponseResponseTypeDef = TypedDict(
-    "UpdateServerResponseResponseTypeDef",
+UpdateServerResponseTypeDef = TypedDict(
+    "UpdateServerResponseTypeDef",
     {
         "ServerId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredUpdateUserRequestTypeDef = TypedDict(
-    "_RequiredUpdateUserRequestTypeDef",
+_RequiredUpdateUserRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateUserRequestRequestTypeDef",
     {
         "ServerId": str,
         "UserName": str,
     },
 )
-_OptionalUpdateUserRequestTypeDef = TypedDict(
-    "_OptionalUpdateUserRequestTypeDef",
+_OptionalUpdateUserRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateUserRequestRequestTypeDef",
     {
         "HomeDirectory": str,
         "HomeDirectoryType": HomeDirectoryTypeType,
@@ -849,14 +853,14 @@ _OptionalUpdateUserRequestTypeDef = TypedDict(
 )
 
 
-class UpdateUserRequestTypeDef(
-    _RequiredUpdateUserRequestTypeDef, _OptionalUpdateUserRequestTypeDef
+class UpdateUserRequestRequestTypeDef(
+    _RequiredUpdateUserRequestRequestTypeDef, _OptionalUpdateUserRequestRequestTypeDef
 ):
     pass
 
 
-UpdateUserResponseResponseTypeDef = TypedDict(
-    "UpdateUserResponseResponseTypeDef",
+UpdateUserResponseTypeDef = TypedDict(
+    "UpdateUserResponseTypeDef",
     {
         "ServerId": str,
         "UserName": str,
